@@ -24,12 +24,16 @@ import time
 
 from debtcollector import removals
 import iso8601
-from time import monotonic as now  # noqa
 import pytz
 import six
 
 from oslo_utils import reflection
 
+if hasattr(time, 'monotonic'):
+    now = time.monotonic
+else:
+    from time import monotonic as now  # noqa
+
 # ISO 8601 extended time format with microseconds
 _ISO8601_TIME_FORMAT_SUBSECOND = '%Y-%m-%dT%H:%M:%S.%f'
 _ISO8601_TIME_FORMAT = '%Y-%m-%dT%H:%M:%S'
